
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.28.5',
    'branch_nick': 'release-1.28',
    'revision_id': '4da26fdb39e4d0bac0a903166d94b0e077159299',
    'revno': 11609
}
